@@ -33,7 +33,7 @@ namespace thumbnailer
 namespace internal
 {
 
-auto do_close = [](int fd)
+static auto do_close = [](int fd)
 {
     if (fd >= 0)
     {
@@ -42,7 +42,7 @@ auto do_close = [](int fd)
 };
 typedef lomiri::util::ResourcePtr<int, decltype(do_close)> FdPtr;
 
-auto do_unlink = [](std::string const& filename)
+static auto do_unlink = [](std::string const& filename)
 {
     ::unlink(filename.c_str());
 };
